==> OSCA.basic_1.6.2.tar.gz: OSCA.basic/inst/doc/book/index.md <==
--- 
title: "Basics of Single-Cell Analysis with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.16-bioc/R/library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.basic"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Peter Hickey [cre]<br/>
  **Version:** 1.6.2<br/>
  **Modified:** 2023-02-15<br/>
  **Compiled:** 2023-02-20<br/>
  **Environment:** R version 4.2.2 (2022-10-31), Bioconductor 3.16<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2023<br/>
  **Source:** https://github.com/OSCA-source/OSCA.basic"
url: "https://github.com/OSCA-source/OSCA.basic"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the basic analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.16/OSCA).
This describes the steps of a simple single-cell RNA-seq analysis, involving quality control,
    normalization, various forms of dimensionality reduction, clustering into subpopulations, 
    detection of marker genes, and annotation of cell types. It is intended for users who already
    have some familiarity with R and want to get hands-on with some basic single-cell analyses.

==> OSCA.basic_1.8.0.tar.gz: OSCA.basic/inst/doc/book/index.md <==
--- 
title: "Basics of Single-Cell Analysis with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.17-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.basic"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Peter Hickey [cre]<br/>
  **Version:** 1.8.0<br/>
  **Modified:** 2023-02-15<br/>
  **Compiled:** 2023-04-26<br/>
  **Environment:** R version 4.3.0 RC (2023-04-13 r84269), Bioconductor 3.17<br/>
  **License:** CC BY 4.0<br/>
  **Copyright:** Bioconductor, 2023<br/>
  **Source:** https://github.com/OSCA-source/OSCA.basic"
url: "https://github.com/OSCA-source/OSCA.basic"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the basic analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.17/OSCA).
This describes the steps of a simple single-cell RNA-seq analysis, involving quality control,
    normalization, various forms of dimensionality reduction, clustering into subpopulations, 
    detection of marker genes, and annotation of cell types. It is intended for users who already
    have some familiarity with R and want to get hands-on with some basic single-cell analyses.
